@@ -12,12 +12,13 @@ class QHBoxLayout;
 class QScrollArea;
 class QTimeZone;
 
-namespace EventViews {
+namespace EventViews
+{
 class Agenda;
 class AgendaView;
 
 class Prefs;
-typedef QSharedPointer<Prefs> PrefsPtr;
+using PrefsPtr = QSharedPointer<Prefs>;
 
 class TimeLabelsZone : public QWidget
 {
